@@ -3,7 +3,6 @@ CREATE TABLE IF NOT EXISTS products (
 	title    TEXT   NOT NULL,
 	subtitle TEXT   NOT NULL,
 	summary  TEXT   NOT NULL,
-	pictures TEXT[]     NULL,
 	price    INT    NOT NULL,
 	stock    INT    NOT NULL,
 	CONSTRAINT positive_stock CHECK (stock >= 0)
@@ -22,6 +21,8 @@ CREATE TABLE IF NOT EXISTS orders (
 	total    INT NOT NULL,
 	discount VARCHAR(20) REFERENCES discounts UNIQUE,
 
+	stripe_token TEXT,
+
 	-- DELIVERY
 	first_name   VARCHAR(20) NOT NULL,
 	last_name    VARCHAR(20) NOT NULL,
