@@ -6,7 +6,7 @@ use warnings;
 use utf8;
 use parent qw/Plack::Component/;
 
-our $VERSION = '0.000_002';
+our $VERSION = '0.000_003';
 
 use DBIx::Simple;
 use File::Slurp;
@@ -205,7 +205,7 @@ sub details_app {
 	my $title = $db{$$}->select(products => 'title', {product => $id})->list;
 	my @pics = <static/fullpics/$id-*>;
 	my $slug = make_slug $title;
-	$tree->find('title')->replace_content("Pictures of $title");
+	$tree->find('title')->replace_content("Pictures of $title | ledparts4you");
 	$tree->find('h2')->replace_content($title);
 	$tree->look_down(rel => 'canonical')->attr(href => "/details/$id/$slug");
 	$tree->fid('pictures')->iter3(\@pics, \&details_list_element);
@@ -231,7 +231,7 @@ sub app {
 			my $app = shift;
 			sub {
 				my $res = $app->(@_);
-				push @{$res->[2]}, $footer;
+				push @{$res->[2]}, $footer if $res->[0] == 200;
 				$res;
 			}
 		};
